California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 055 - TAX EXTENSION TO FUND EDUCATION AND HEALTHCARE. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1390602 | COMMON SENSE KIDS ACTION, INC., YES ON PROPS. 55 AND 56 (NONPROFIT 501 (C) (4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385538 | CALIFORNIA KIDS CAMPAIGN, YES ON PROPS 55 & 56, SPONSORED AND MAJOR FUNDING BY COMMON SENSE KIDS ACTION, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385886 | NO ON PROPOSITION 55, CALIFORNIA'S FUTURE PAC, SPONSORED BY THE KERSTEN INSTITUTE FOR GOVERNANCE & PUBLIC POLICY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1384591 | MILLION VOTER PROJECT ACTION FUND - YES ON 55 AND 57, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1391170 | MILLION VOTER PROJECT ACTION FUND - YES ON 55, 56, 57, 58, 62, AND NO ON 66, SPONSORED BY SOCIAL JUSTICE ADVOCATES AND ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372760 | PICO CALIFORNIA - YES ON 55, 56, AND 57 (NON PROFIT 501 (C) (3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1381382 | YES ON 55 - CALIFORNIANS FOR BUDGET STABILITY, SPONSORED BY TEACHERS, HEALTH CARE PROVIDERS, DOCTORS AND LABOR ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
931704 | UNITED TEACHERS LOS ANGELES-POLITICAL ACTION COUNCIL OF EDUCATORS (PACE) ISSUES, A COMMITTEE FOR PROPOSITIONS 55 AND 58 | SUPPORT